@@ -1,15 +1,9 @@
-
-################################################################################
-#                                                                              #
-#                        extra_functions for keyvaluem1                        #
-#                                                                              #
-################################################################################
-
 #'Extra functions to apply to decoded variables using decode
 #'
 #'See section "extra_functions" at the \link{decode} help page!
 #'
-#' @param x The decoded variable to be further processed. This argument should not be set by the user.
+#' @param x The decoded variable to be further processed. 
+#' This argument should not be set by the user.
 #' It is used only internally by the function from which it is called.
 #' @name extra_functions
 #' @export
@@ -31,10 +25,10 @@ kungalv2Fyrbodal <- function(x){
 #' @export
 real_names <- function(x){
     x <- as.character(x)
-    x[x == "Kungalv"]  <- "Kung\u00E4lv"
+    x[x == "Kungalv"]        <- "Kung\u00E4lv"
     x[x == "Norra_Halland"]  <- "Norra Halland"
-    x[x == "Sodra_Alvsborg"]  <- "S\u00F6dra \u00C4lvsborg"
-    x[x == "Storgoteborg"]  <- "Storg\u00F6teborg"
+    x[x == "Sodra_Alvsborg"] <- "S\u00F6dra \u00C4lvsborg"
+    x[x == "Storgoteborg"]   <- "Storg\u00F6teborg"
     x
 }
 
@@ -43,3 +37,16 @@ real_names <- function(x){
 short_region_names <- function(x){
     gsub("Region ", "", as.character(x))
 }
+
+#' @rdname extra_functions
+#' @export
+sjukhus_rc_namn <- function(x) {
+  decode(x, "sjukhus_rc_code2klartext")
+}
+  
+
+#' @rdname extra_functions
+#' @export
+forvaltning_rc_namn <- function(x) {
+  decode(x, "forvaltning_rc_code2klartext")
+}
